@@ -350,7 +350,17 @@ class Table(View):
               hugo_file.write("draft: false\n")
               hugo_file.write(f"type: {public_name}\n")
               hugo_file.write("---\n")
-              hugo_file.write("I think this then appears as the content\n")
+              hugo_file.write(f"## {title_field}\n")
+              hugo_file.write(f"### {name_field}\n")
+              hugo_file.write(f"{desc_field}\n\n")
+              if img_field != None:
+                hugo_file.write("::: {.column-margin}\n")
+                hugo_file.write(f"<img src=\"{img_field}/full/400,/0/default.jpg\">\n\n")
+                hugo_file.write(f":::\n\n")
+              url_field = self.output_map(item_data, "URL")
+              if url_field != None:
+                hugo_file.write(f"## Collection Website\n")
+                hugo_file.write(f"<a href=\"{url_field}\"/>{title_field}</a> ({author_field})\n")
 
             # Need to map from our fields to the known Quarto fields (date, author, title..) based on
             # the config file settings
